package tpxmlsql;

import java.io.FileOutputStream;
import java.io.OutputStream;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import javax.xml.stream.XMLOutputFactory;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamWriter;

import bd.ConfigConnection;

public class SQL2XML {

    public static void main(String[] args) {
        try {
            Connection connection = ConfigConnection.getConnection( args[ 0 ] );
            String id = args[ 1 ];
            OutputStream out = ( args.length == 2 ) ? (OutputStream) System.out : new FileOutputStream( args[ 2 ] );

            SQL2XML.convert( connection, id, out );
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static void convert( Connection connection, String id, OutputStream output ) throws SQLException, XMLStreamException {
        PreparedStatement statement = connection.prepareStatement(
            "SELECT ID,PO.PN,QTY,PRODUCT,PRICE,CURRENCY " +
            "FROM PO, PRODUCTS " +
            "WHERE PO.PN = PRODUCTS.PN " +
            "AND ID = ? " +
            "ORDER BY CURRENCY" );
        statement.setInt( 1, Integer.parseInt( id ) );
        statement.execute();
        ResultSet result = statement.getResultSet();
        XMLOutputFactory of = XMLOutputFactory.newInstance();
        XMLStreamWriter writer = of.createXMLStreamWriter( output );
        writer.writeStartDocument();
        writer.writeStartElement( "order" );
        writer.writeAttribute( "id", id );
        boolean next = result.next();
        while ( next ) {
            String currency = result.getString( "CURRENCY" );
            writer.writeStartElement( currency );
            writer.flush();
            while ( next && result.getString( "CURRENCY" ).equals( currency ) ) {
                writer.writeStartElement( "item" );
                writer.writeAttribute( "part-number", result.getString( "PN" ) );
                writer.writeAttribute( "price", result.getString( "PRICE" ) );
                writer.writeAttribute( "quantity", result.getString( "QTY" ) );
                writer.writeCharacters( result.getString( "PRODUCT" ) );
                writer.writeEndElement();
                next = result.next();
                writer.flush();
            }
            writer.writeEndElement();
        }
        writer.writeEndElement();
        writer.writeEndDocument();
        writer.flush();
    }

}
